Rastreie com que frequência pessoas, empresas ou locais aparecem juntos ao longo do tempo
Rastreie com que frequência pessoas, empresas ou locais aparecem juntos ao longo do tempo. Veja se a cobertura é positiva, negativa ou neutra e filtre por fonte
Parâmetros de entrada
| Parâmetro | Descrição | Tipo | Padrão | Obrigatório |
|---|---|---|---|---|
| entity.id | Vários IDs de entidade, separados por vírgulas. | string | Sim | |
| published_at.start | Data de início para o intervalo de tempo. | string | Sim | |
| published_at.end | Data de término para período de tempo. | string | Sim | |
| sort.by | Ordenar por pontuação de sentimento. | string | Sim | |
| sort.order | Ordem decrescente. | string | Sim | |
| is_duplicate | Excluir duplicatas. | integer | 0 | Sim |
| api_key | Sua chave API | string | Sim | |
| per_page | Número máximo de artigos a serem recuperados | integer | 50 | Não |
Exemplos de fluxo de trabalho
Veja quais pessoas, organizações e locais aparecem juntos em artigos:
curl -X GET "https://api.apitube.io/v1/news/everything?entity.id=1278268,1282301&published_at.start=2023-01-01&published_at.end=2023-12-31&sort.by=sentiment.overall.score&sort.order=desc&api_key=YOUR_API_KEY"
Rastreie menções de uma pessoa, organização ou local ao longo do tempo:
curl -X GET "https://api.apitube.io/v1/news/everything?entity.id=1278268&published_at.start=2022-01-01&published_at.end=2023-12-31&per_page=100&sort.by=published_at&sort.order=asc&api_key=YOUR_API_KEY"
Veja quais pessoas, organizações e locais são mencionados juntos:
curl -X GET "https://api.apitube.io/v1/news/everything?entity.id=1278268&organization.name=Tesla&published_at.start=2023-01-01&published_at.end=2023-12-31&sort.by=published_at&api_key=YOUR_API_KEY"
Veja como uma pessoa, organização ou local afeta se a cobertura de mercado é positiva, negativa ou neutra:
curl -X GET "https://api.apitube.io/v1/news/everything?entity.id=1278268,1282301&category.id=medtop:04000000&sentiment.overall.score.min=0.7&published_at.start=2023-01-01&sort.by=sentiment.overall.score&sort.order=desc&api_key=YOUR_API_KEY"
Exemplos relacionados
- Encontre com quais organizações uma pessoa é mencionada
- Análise de reputação da marca
- Acompanhe seus concorrentes
- Filtre artigos que mencionam pessoas
- Ordene por pontuação de engajamento
Receita para cURL
curl --location --globoff --request POST 'https://api.apitube.io/v1/news/everything?entity.id=1278268%2C1282301&published_at.start=2023-01-01&published_at.end=2023-12-31&sort.by=sentiment.overall.score&sort.order=desc&is_duplicate=0&api_key=YOUR_API_KEY&per_page=50' \
--header 'Content-Type: application/json'
Receita para Python
import requests
url = "https://api.apitube.io/v1/news/everything"
querystring = {
"entity.id": "1278268,1282301",
"published_at.start": "2023-01-01",
"published_at.end": "2023-12-31",
"sort.by": "sentiment.overall.score",
"sort.order": "desc",
"is_duplicate": 0,
"api_key": "YOUR_API_KEY",
"per_page": 50
}
response = requests.request("GET", url, params=querystring)
print(response.text)
Receita para Javascript
import axios from "axios"
const options = {
method: 'GET',
url: 'https://api.apitube.io/v1/news/everything',
params: {
"entity.id": "1278268,1282301",
"published_at.start": "2023-01-01",
"published_at.end": "2023-12-31",
"sort.by": "sentiment.overall.score",
"sort.order": "desc",
"is_duplicate": 0,
"api_key": "YOUR_API_KEY",
"per_page": 50
}};
axios.request(options).then(function (response) {
console.log(response.data);
}).catch(function (error) {
console.error(error);
});
Receita para PHP
require 'vendor/autoload.php';
use GuzzleHttp\Client;
$client = new Client();
$response = $client->request('GET', 'https://api.apitube.io/v1/news/everything', [
'query' => [
'entity.id' => '1278268,1282301',
'published_at.start' => '2023-01-01',
'published_at.end' => '2023-12-31',
'sort.by' => 'sentiment.overall.score',
'sort.order' => 'desc',
'is_duplicate' => 0,
'api_key' => 'YOUR_API_KEY',
'per_page' => 50,
],
]);
echo $response->getBody();
Receita para Java
OkHttpClient client = new OkHttpClient().newBuilder().build();
MediaType mediaType = MediaType.parse("application/json");
RequestBody body = RequestBody.create(mediaType, "");
Request request = new Request.Builder()
.url("https://api.apitube.io/v1/news/everything?entity.id=1278268%2C1282301&published_at.start=2023-01-01&published_at.end=2023-12-31&sort.by=sentiment.overall.score&sort.order=desc&is_duplicate=0&api_key=YOUR_API_KEY&per_page=50")
.method("POST", body)
.addHeader("Content-Type", "application/json")
.build();
Response response = client.newCall(request).execute();